#!/bin/sh
set -e
set -x

if [ "$#" -lt 2 ]; then
    echo 'Need two arguments: service name and DB name.'
    false
fi
if [ ! "$1" = "pleroma_otp" ] && [ ! "$1" = "pleroma_source" ] && [ ! "$1" = "peertube" ]; then
    echo "Need legal service name (pleroma_otp or pleroma_source or peertube)."
    false
fi
app="$1"
db_name="$2"
service="$1"
if [ "${app}" = "pleroma_source" ] || [ "${app}" = "pleroma_otp" ]; then
    service=pleroma
fi

service "${service}" stop

mv "/home/plom/${service}_backup.tar" /tmp/
cd /tmp
tar xf "${service}_backup.tar"

su postgres -c "pg_restore -c -1 -d ${db_name} ${service}_backup/${db_name}.pgdump"
rm "${service}_backup/${db_name}.pgdump"

cd "${service}_backup"
for path in $(find . -type f); do
    if [ "${app}" = "pleroma_source" ]; then
        if [ "${path}" = './opt/pleroma/config/prod.secret.exs' ]; then
            continue  # skip file that contains passwords
        fi
    fi
    target_path=$(echo "${path}" | cut -c2-)
    source_path=$(realpath "${path}")
    dir=$(dirname "${target_path}")
    mkdir -p "${dir}"
    cp -a "${source_path}" "${target_path}"
done

# TODO: Horrible hack, improve.
if [ "${app}" = "pleroma_otp" ]; then
    db_pw=$(cat /etc/pleroma/config.exs | grep password | sed 's/[ ]*password\: *//g' | sed 's/,//g' | sed 's/"//g')
elif [ "${app}" = "peertube" ]; then
    db_pw=$(cat /var/www/peertube/config/production.yaml | grep password | head -1 | sed "s/[ ]*password\: *//g" | sed "s/'//g")
fi
if [ "${app}" = "pleroma_otp" ] || [ "${app}" = "peertube" ]; then
    su postgres -lc "psql -c \"ALTER USER ${service} WITH PASSWORD '${db_pw}';\""
fi

service "${service}" start
